@@ -43,6 +43,7 @@ from .typings import (
     _MasterQuery,
     OnlyColumn,
     SquashedSqueries,
+    JustAColumn,
 )
 
 # Let's add a little bit of 'black' magic here.
@@ -63,7 +64,7 @@ class Table:
         self,
         parent,  # type: ignore
         table: str,
-        __columns: Optional[Iterable[Column]] = None, # type: ignore
+        __columns: Optional[Iterable[Column]] = None,  # type: ignore
     ) -> None:
         if parent.closed:
             raise ConnectionError("Connection to database is already closed.")
@@ -107,10 +108,29 @@ class Table:
         except Exception:  # pylint: disable=broad-except
             return 1
 
-    def _raw_exec(self, query: str, data: dict[str, Any]):
-        """No thread safe :("""
+    # def _raw_exec(self, query: str, data: dict[str, Any]):
+    #     """No thread safe :("""
+    #     cursor = self._sql.cursor()
+    #     cursor.execute(query, data)
+    #     return cursor
+
+    def _exec(
+        self,
+        query: str,
+        data: dict[str, Any] | list[dict[str, Any]],
+        which: Literal["execute", "executemany"] = "execute",
+    ):
+        """Execute a sql query"""
         cursor = self._sql.cursor()
-        cursor.execute(query, data)
+        fn = cursor.execute if which == "execute" else cursor.executemany
+        try:
+            fn(query, data)
+        except OperationalError as exc:
+            exc.add_note(f"SQL query: {query}")
+            exc.add_note(
+                f"There's about {1 if isinstance(data, dict) else len(data)} value(s) inserted"
+            )
+            raise exc
         return cursor
 
     def _control(self):
@@ -132,7 +152,7 @@ class Table:
         condition: Condition = None,
         limit: int = 0,
         order: Optional[Orders] = None,
-        commit: bool = True
+        commit: bool = True,
     ):
         """Delete row or rows
 
@@ -148,8 +168,7 @@ class Table:
         """
         query, data = build_delete(self._table, condition, limit, order)  # type: ignore
         self._control()
-        cursor = self._sql.cursor()
-        cursor.execute(query, data)
+        cursor = self._exec(query, data)
         rcount = cursor.rowcount
         if commit:
             self._sql.commit()
@@ -179,8 +198,7 @@ class Table:
         """
         query, _ = build_insert(self._table, data)  # type: ignore
         self._control()
-        cursor = self._sql.cursor()
-        cursor.execute(query, data)
+        cursor = self._exec(query, data)
         rlastrowid = cursor.lastrowid
         self._sql.commit()
         if commit:
@@ -198,8 +216,7 @@ class Table:
         """
         self._control()
         query, _ = build_insert(self._table, datas[0])  # type: ignore
-        cursor = self._sql.cursor()
-        cursor.executemany(query, datas)
+        self._exec(query, datas, "executemany")
         if commit:
             self._sql.commit()
         else:
@@ -215,7 +232,7 @@ class Table:
         data: Data | None = None,
         limit: int = 0,
         order: Optional[Orders] = None,
-        commit: bool = True
+        commit: bool = True,
     ):
         """Update rows of current table
 
@@ -236,8 +253,7 @@ class Table:
             self._table, data, condition, limit, order
         )  # type: ignore
         self._control()
-        cursor = self._sql.cursor()
-        cursor.execute(query, data)
+        cursor = self._exec(query, data)
         rcount = cursor.rowcount
         if commit:
             self._sql.commit()
@@ -318,8 +334,7 @@ class Table:
             self._table, condition, only, limit, offset, order
         )  # type: ignore
         with self._sql:
-            cursor = self._sql.cursor()
-            cursor.execute(query, data)
+            cursor = self._exec(query, data)
             data = cursor.fetchall()
             if squash:
                 return crunch(data)
@@ -375,7 +390,7 @@ class Table:
 
         if page < 0:
             page = 0
-            order = 'desc' if order in ('asc', None) else 'asc' # type: ignore
+            order = "desc" if order in ("asc", None) else "asc"  # type: ignore
         self._control()
         self._query_control()
         start = page * length
@@ -385,8 +400,7 @@ class Table:
             )  # type: ignore
             crunched = squash
             with self._sql:
-                cursor = self._sql.cursor()
-                cursor.execute(query, data)
+                cursor = self._exec(query, data)
                 fetched = cursor.fetchmany(length)
                 if len(fetched) == 0:
                     return
@@ -416,10 +430,19 @@ class Table:
     ) -> Query:
         pass
 
+    @overload
     def select_one(
         self,
         condition: Condition = None,
-        only: OnlyColumn | ParsedFn = "*",
+        only: JustAColumn = "_COLUMN",
+        order: Optional[Orders] = None,
+    ) -> Any:
+        pass
+
+    def select_one(
+        self,
+        condition: Condition = None,
+        only: OnlyColumn | JustAColumn | ParsedFn = "*",
         order: Optional[Orders] = None,
     ):
         """Select one data
@@ -438,13 +461,14 @@ class Table:
             self._table, condition, only, 1, 0, order
         )  # type: ignore
         with self._sql:
-            cursor = self._sql.cursor()
-            cursor.execute(query, data)
+            cursor = self._exec(query, data)
             data = cursor.fetchone()
             if isinstance(only, ParsedFn):
                 return data[only.parse_sql()[0]]
             if not data:
                 return Row()
+            if isinstance(only, str) and only != "*":
+                return data[only]
             return data
 
     def exists(self, condition: Condition = None):
